package com.ruoyi.web.pshMarks.service;

import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.web.pshMarks.mapper.PshMarksMapper;
import com.ruoyi.web.sspManage.mapper.SspMapper;
import com.ruoyi.web.sspMarks.domain.SspMarkfileinfo;
import com.ruoyi.web.sspMarks.domain.SspMarks;
import com.ruoyi.web.sspMarks.domain.SspMarksflow;
import com.ruoyi.web.utils.MultipartFileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.*;


/**
 * 随手拍留痕上报 服务层实现
 *
 * @author gwb
 * @date 2021-04-06
 */
@Service
public class PshMarksServiceImpl implements IPshMarksService
{
	@Autowired
	private PshMarksMapper pshMarksMapper;

	@Autowired
	private SspMapper sspMapper;


	/**
	 * 查询随手拍留痕上报信息
	 *
	 * @param id 随手拍留痕上报ID
	 * @return 随手拍留痕上报信息
	 */
	@Override
	public SspMarks selectSspMarksById(Integer id)
	{
		return pshMarksMapper.selectSspMarksById(id);
	}

	/**
	 * 查询随手拍留痕上报列表
	 *
	 * @param sspMarks 随手拍留痕上报信息
	 * @return 随手拍留痕上报集合
	 */
	@Override
	public List<SspMarks> selectSspMarksList(SspMarks sspMarks)
	{
		return pshMarksMapper.selectSspMarksList(sspMarks);
	}

	/**
	 * 新增随手拍留痕上报
	 *
	 * @param sspMarks 随手拍留痕上报信息
	 * @return 结果
	 */
	@Override
	public int insertSspMarks(SspMarks sspMarks)
	{
		return pshMarksMapper.insertSspMarks(sspMarks);
	}

	/**
	 * 修改随手拍留痕上报
	 *
	 * @param sspMarks 随手拍留痕上报信息
	 * @return 结果
	 */
	@Override
	public int updateSspMarks(SspMarks sspMarks)
	{
		return pshMarksMapper.updateSspMarks(sspMarks);
	}

	/**
	 * 保存随手拍留痕上报
	 *
	 * @param sspMarks 随手拍留痕上报信息
	 * @return 结果
	 */
	@Override
	public int saveSspMarks(SspMarks sspMarks)
	{
		String id = sspMarks.getId();
		int rows = 0;
		if (StringUtils.isNotNull(id))
		{
			rows = pshMarksMapper.updateSspMarks(sspMarks);
		}
		else
		{
			rows = pshMarksMapper.insertSspMarks(sspMarks);
		}
		return rows;
	}

	/**
	 * 删除随手拍留痕上报对象
	 *
	 * @param ids 需要删除的数据ID
	 * @return 结果
	 */
	@Override
	public int deleteSspMarksByIds(String ids)
	{
		return pshMarksMapper.deleteSspMarksByIds(Convert.toStrArray(ids));
	}

	/**
	 * 新增留痕数据上报
	 *
	 * @param sspMarks
	 * @return
	 */
	@Override
	public Object saveMarksAndMore(SspMarks sspMarks) {
		String result = "NO";
		sspMarks.setMarksTime(sspMarks.getMarksTime() + ":00");
		String simpleUUID = IdUtil.simpleUUID();
		sspMarks.setId(simpleUUID);
		//基本信息
		int m = pshMarksMapper.addSspMarks(sspMarks);

		//审批流创建, mainId取基本信息的id
		SspMarksflow sspMarksflow = new SspMarksflow();
		sspMarksflow.setMainId(sspMarks.getId());
		sspMarksflow.setCheckState(sspMarks.getCheckState());
		sspMarksflow.setMarksRemark(sspMarks.getMarksRemark());
		sspMarksflow.setCreateTime(sspMarks.getCreateDate());
		sspMarksflow.setCreateUser(sspMarks.getCreateUser());

		int b = sspMapper.saveSspMarkFlow(sspMarksflow);
		//图片
		int c = 0;
		JSONArray JSONArray = com.alibaba.fastjson.JSONArray.parseArray(sspMarks.getMarksPicture());

		for (int i = 0; i < JSONArray.size(); i++) {
			String name = "sspImg-"+ UUID.randomUUID()+".jpg";
			String objImg64 = JSONArray.get(i).toString();
			String imgBase64One = objImg64.substring(0, objImg64.indexOf(","));
			String imgBase64 = objImg64.substring(imgBase64One.length()+1, objImg64.length());
			SspMarkfileinfo sspMarkfileinfo = new SspMarkfileinfo();
			Map<String, Object> imgMap = null;
			try {
				MultipartFile file = MultipartFileUtils.base64ToMultipartFile(objImg64);
				// 上传文件路径
				String filePath = RuoYiConfig.getUploadPath();
				// 上传并返回新文件名称
				String fileName = FileUploadUtils.upload(filePath, file);
				sspMarkfileinfo.setFileUrl(fileName);
			} catch (Exception e) {
				e.printStackTrace();
			}
			sspMarkfileinfo.setFileType(0);
			sspMarkfileinfo.setCreateUser(sspMarks.getCreateUser());
			sspMarkfileinfo.setExternalId(sspMarksflow.getId());
			c = sspMapper.saveMarkFileInfo(sspMarkfileinfo);
		}
		//视频
		if(org.apache.commons.lang3.StringUtils.isNotBlank(sspMarks.getMarksVideo())) {
			SspMarkfileinfo sspMarkfileinfo = new SspMarkfileinfo();
			sspMarkfileinfo.setFileUrl(sspMarks.getMarksVideo());
			sspMarkfileinfo.setFileType(1);
			sspMarkfileinfo.setCreateUser(sspMarks.getCreateUser());
			sspMarkfileinfo.setExternalId(sspMarksflow.getId());
			sspMapper.saveMarkFileInfo(sspMarkfileinfo);
		}

		/**
		 * 更新图片、视频url
		 */
		SspMarkfileinfo sspMarkfileinfo = new SspMarkfileinfo();
		sspMarkfileinfo.setExternalId(sspMarksflow.getId());
		String picture = "";
		List<SspMarkfileinfo> sspMarkfileinfoList = pshMarksMapper.queryPictureUrl(sspMarkfileinfo);
		StringBuilder sb = new StringBuilder();
		for (int i = 0; i < sspMarkfileinfoList.size(); i++) {
			sb.append(sspMarkfileinfoList.get(i).getFileUrl()).append(",");
		}
		picture = sb.toString().substring(0,sb.toString().length()-1);
		Map<String, Object> parmsMap = new HashMap<>();
		parmsMap.put("smarkUrl", picture);
		parmsMap.put("id", sspMarks.getId());
		pshMarksMapper.updateSmarkUrl(parmsMap);

		parmsMap.put("picture", sspMarkfileinfoList.get(0).getFileUrl());
		//展示一张图片
		pshMarksMapper.updatePicture(parmsMap);


		List<SspMarkfileinfo> vidceoSspMark = pshMarksMapper.queryVideoUrl(sspMarkfileinfo);
		parmsMap.put("video", vidceoSspMark == null || vidceoSspMark.size() == 0?"":vidceoSspMark.get(0).getFileUrl());
		pshMarksMapper.updateVideo(parmsMap);
		if( m > 0 && b> 0 && c > 0) {
			result = "OK";
		}
		return result;
	}

	@Override
	public int saveQualityMark(JSONObject jsonObject) {
		Map<String, Object> map = new HashMap<>();
		map.put("projectId",jsonObject.containsKey("projectId")?jsonObject.getString("projectId"):"");
		map.put("workTime",jsonObject.containsKey("workTime")?jsonObject.getString("workTime"):"");
		map.put("positionId",jsonObject.containsKey("projectGhId")?jsonObject.getString("projectGhId"):"");
		map.put("paragrapId",jsonObject.containsKey("projectPlaceId")?jsonObject.getString("projectPlaceId"):"");
		map.put("locationId",jsonObject.containsKey("projectLocationId")?jsonObject.getString("projectLocationId"):"");
		map.put("conclusion",jsonObject.containsKey("conclusion")?jsonObject.getString("conclusion"):"");
		map.put("szUser",jsonObject.containsKey("SZUser")?jsonObject.getString("SZUser"):"");
		map.put("zjUserId",jsonObject.containsKey("ZJUserId")?jsonObject.getString("ZJUserId"):"");
		map.put("zbUserId",jsonObject.containsKey("ZBUserId")?jsonObject.getString("ZBUserId"):"");
		map.put("jlUserId",jsonObject.containsKey("JLUserId")?jsonObject.getString("JLUserId"):"");
		map.put("createUser",jsonObject.containsKey("create_user")?jsonObject.getString("create_user"):"");
		String beforeImgs = "";
		String afterImgs  = "";
		if(jsonObject.containsKey("beforeImgSrcList")){
			JSONArray jsonArray = jsonObject.getJSONArray("beforeImgSrcList");
			if(jsonArray.size() > 0){
				for(int i = 0;i<jsonArray.size();i++){
					if(i==0){
						beforeImgs = jsonArray.getString(i);
					}else{
						beforeImgs += (","+jsonArray.getString(i));
					}
				}
			}
		}
		if(jsonObject.containsKey("afterImgSrcList")){
			JSONArray jsonArray = jsonObject.getJSONArray("afterImgSrcList");
			if(jsonArray.size() > 0){
				for(int i = 0;i<jsonArray.size();i++){
					if(i==0){
						afterImgs = jsonArray.getString(i);
					}else{
						afterImgs += (","+jsonArray.getString(i));
					}
				}
			}
		}
		map.put("beforeImgs",beforeImgs);
		map.put("afterImgs",afterImgs);
		int i = pshMarksMapper.insertSspQualityMark(map);
		if(i == 1){
			int mark_id = Integer.parseInt(map.get("markId").toString());
			Map<String,Object> sp = new HashMap<>();
			sp.put("markId",mark_id);
			//总包审核人
			if(jsonObject.containsKey("ZBUserId")){
				sp.put("userId",jsonObject.getString("ZBUserId"));
				sp.put("userName",jsonObject.getString("ZBUserName"));
				sp.put("loginName",jsonObject.getString("ZBUserPhone"));
				sp.put("sort",1);
				pshMarksMapper.insertSspQualityMarkApprove(sp);
			}
			if(jsonObject.containsKey("JLUserId")){
				sp.put("userId",jsonObject.getString("JLUserId"));
				sp.put("userName",jsonObject.getString("JLUserName"));
				sp.put("loginName",jsonObject.getString("JLUserPhone"));
				sp.put("sort",2);
				pshMarksMapper.insertSspQualityMarkApprove(sp);
			}
		}
		return i;
	}

	/**
	 * 根据流程表id 和文件类型查询图片
	 *
	 * @param sspMarks
	 * @return
	 */
	@Override
	public List<SspMarks> queryPicture(SspMarks sspMarks) {

		return pshMarksMapper.queryPicture(sspMarks);
	}

	/**
	 * 视频
	 *
	 * @param sspMarks
	 * @return
	 */
	@Override
	public List<SspMarks> queryVideo(SspMarks sspMarks) {
		return pshMarksMapper.queryVideo(sspMarks);
	}

	/**
	 * 查询留痕上报列表
	 *
	 * @param sspMarks
	 * @return
	 */
	@Override
	public Map<String, Object> queryMarksList(SspMarks sspMarks) {
		Map<String, Object> returnMap = new HashMap<>();
		String projectName = "";
		List<SspMarks> publishMarks = new ArrayList<>();
		List<SspMarks> publishMarksMy = new ArrayList<>();
		//审核通过
		if("4".equals(sspMarks.getCheckState())) {
			publishMarks = pshMarksMapper.selectSspMarksList(sspMarks);
			for(SspMarks dbSspMarks:publishMarks){
				projectName = dbSspMarks.getMarksLocation();
			}
		} else if("".equals(sspMarks.getCheckState()) ) {

			/***
			 * 初始化页面
			 */
			sspMarks.setCheckState("4");
			publishMarks = pshMarksMapper.selectSspMarksList(sspMarks);
			for(SspMarks dbSspMarks:publishMarks){
				projectName = dbSspMarks.getMarksLocation();
			}

			Map<String, Object> noPassMap = new HashMap<>();
			noPassMap.put("checkState", "1");
			noPassMap.put("projectId", sspMarks.getProjectId());

			Map<String, Object> daiPassMap = new HashMap<>();
			daiPassMap.put("checkState", "0");
			daiPassMap.put("projectId", sspMarks.getProjectId());
			//没通过
			List<SspMarks> noPass = pshMarksMapper.queryByCheckState(noPassMap);
			for(SspMarks npSspMarks:noPass) {
				publishMarksMy.add(npSspMarks);
			}
			//待通过
			List<SspMarks> daiPass = pshMarksMapper.queryByCheckState(daiPassMap);
			for(SspMarks daiPassSmark:daiPass) {
				publishMarksMy.add(daiPassSmark);
			}

		} else if("-1".equals(sspMarks.getCheckState())) {

			/**
			 * 搜索
			 *
			 */
			//未通过
			Map<String, Object> noPassMap = new HashMap<>();
			noPassMap.put("checkState", "1");
			noPassMap.put("positionPart", sspMarks.getPositionPart());
			noPassMap.put("projectId", sspMarks.getProjectId());


			Map<String, Object> daiPassMap = new HashMap<>();
			daiPassMap.put("checkState", "0");
			daiPassMap.put("positionPart", sspMarks.getPositionPart());
			daiPassMap.put("projectId", sspMarks.getProjectId());

			//没通过
			List<SspMarks> noPass = pshMarksMapper.queryByCheckState(noPassMap);
			for(SspMarks npSspMarks:noPass) {
				publishMarksMy.add(npSspMarks);
			}
			//待通过
			List<SspMarks> daiPass = pshMarksMapper.queryByCheckState(daiPassMap);
			for(SspMarks daiPassSmark:daiPass) {
				publishMarksMy.add(daiPassSmark);
			}
			//获取项目名称
			for(SspMarks dbSspMarks:publishMarksMy){
				projectName = dbSspMarks.getMarksLocation();
			}
		} else {
			if("0".equals(sspMarks.getCheckState()) || "1".equals(sspMarks.getCheckState())) {
				//待审核,审核通过
				publishMarksMy = pshMarksMapper.selectSspMarksList(sspMarks);
				for(SspMarks dbPublishMarksMy:publishMarksMy){
					projectName = dbPublishMarksMy.getMarksLocation();
				}
			}
		}

		//项目地点
		returnMap.put("projectName", projectName);
		//发布列表
		returnMap.put("publishMarks", publishMarks);
		//发布列表数量
		returnMap.put("publishMarksSize", publishMarks.size());

		//我的发布列表
		returnMap.put("publishMarksMy", publishMarksMy);
		//我的发布列表数量
		returnMap.put("publishMarksMySize", publishMarksMy.size());
		return returnMap;
	}
}
